==> webkit2gtk_2.15.2.orig.tar.xz: webkitgtk-2.15.2/Source/JavaScriptCore/runtime/PrivateName.h <==
/*
 * Copyright (C) 2012, 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/text/SymbolImpl.h>

namespace JSC {

class PrivateName {
public:
    PrivateName()
        : m_uid(StringImpl::createNullSymbol())
    {
    }

    explicit PrivateName(SymbolImpl& uid)
        : m_uid(uid)
    {
    }

    enum DescriptionTag { Description };
    explicit PrivateName(DescriptionTag, const String& description)
        : m_uid(StringImpl::createSymbol(*description.impl()))
    {
    }

    PrivateName(const PrivateName& privateName)
        : m_uid(privateName.m_uid.copyRef())
    {
    }

    PrivateName(PrivateName&&) = default;

    SymbolImpl& uid() const { return const_cast<SymbolImpl&>(m_uid.get()); }

    bool operator==(const PrivateName& other) const { return &uid() == &other.uid(); }
    bool operator!=(const PrivateName& other) const { return &uid() != &other.uid(); }

private:
    Ref<SymbolImpl> m_uid;
};

} // namespace JSC

==> webkit2gtk_2.17.5.orig.tar.xz: webkitgtk-2.17.5/Source/JavaScriptCore/runtime/PrivateName.h <==
/*
 * Copyright (C) 2012, 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/text/SymbolImpl.h>
#include <wtf/text/WTFString.h>

namespace JSC {

class PrivateName {
public:
    PrivateName()
        : m_uid(SymbolImpl::createNullSymbol())
    {
    }

    explicit PrivateName(SymbolImpl& uid)
        : m_uid(uid)
    {
    }

    enum DescriptionTag { Description };
    explicit PrivateName(DescriptionTag, const String& description)
        : m_uid(SymbolImpl::create(*description.impl()))
    {
    }

    PrivateName(const PrivateName& privateName)
        : m_uid(privateName.m_uid.copyRef())
    {
    }

    PrivateName(PrivateName&&) = default;

    SymbolImpl& uid() const { return m_uid; }

    bool operator==(const PrivateName& other) const { return &uid() == &other.uid(); }
    bool operator!=(const PrivateName& other) const { return &uid() != &other.uid(); }

private:
    Ref<SymbolImpl> m_uid;
};

} // namespace JSC
